types

package
v0.2.0-dev Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 21, 2025 License: MIT Imports: 1 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type BPMN

type BPMN struct {
	Pos, Width, Height, X, Y int
	Type, Hash               string
}

BPMN ...

type BPMNGeneric

type BPMNGeneric interface {
	[]OrderedField | []reflect.StructField | map[string]any
}

BPMNGeneric is a generic interface that can be used to represent either a slice of reflect.StructField or a map[string]any.

type OrderedField

type OrderedField struct {
	Name  string // field value or map key
	Value any    // field value or type (BPMN/reflect.StructField/etc.)
	Meta  any    // reflect.StructField or Tags
}

OrderedField represents a field in a struct or map with its name, value, and metadata. Note: Actually not in use and will be implemented in the future.

Jump to