Documentation
¶
Overview ¶
gobpmn.go
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func FromMap ¶
func FromMap[T any](model T, opts ...Options) (parser.BPMNParserRepository, error)
FromMap creates a BPMN model from a generic or typed map definition
func FromStruct ¶
func FromStruct[T HasDefinitions](model T, opts ...Options) (parser.BPMNParserRepository, error)
FromStruct creates a BPMN model from a static struct definition
Types ¶
type HasDefinitions ¶
type HasDefinitions interface {
GetDefinitions() Repository
}
HasDefinitions is an interface for types that have a GetDefinitions method that returns a DefinitionsRepository. This is used to create a BPMN model from a static struct definition.
type Options ¶
Options defines global optional parameters for model creation
func DefaultOptions ¶
func DefaultOptions() Options
DefaultOptions provides sane defaults (e.g., 60s timeout)
type Repository ¶
type Repository = foundation.DefinitionsRepository
DefRepo is a re-exported type from the foundation package
func Definitions ¶
func Definitions() Repository
NewDefinitions creates a new DefinitionsRepository with a new Definitions struct. This is a convenience function to create a new DefinitionsRepository without having to create a new Definitions struct manually.
Directories
¶
| Path | Synopsis |
|---|---|
|
examples
|
|
|
generic_map_simple_process
command
|
|
|
renting_process
command
|
|
|
simple_process
command
|
|
|
small_process
command
|
|
|
typed_map_simple_process
command
|
|
|
internal
|
|
|
pkg
|
|